/**
 * EPhoneBookUI (Electronic Phonebook User Interface) is a
 * user interface for using an electronic phone book of a FIXED SIZE.
 * The interface enables the user to choose an operation
 * from menu and then it shows the results.
 * The user can perform the following operations:
 * 1. Add an entry.
 * 2. Delete an Entry
 * 3. Search an Entry
 */
public class EPhoneBookUI {
	
	//creates a phonebook that can hold 2 entries
	private static PhoneBook book=new PhoneBook(2);
	 
	/**
	 * Presents an interface that enables the user to choose an
	 * operation from a given menu by entering an integer from 1 to 3.
	 * After the operation is done presents a corresponding message.
	*/
	public static void main(String args[]) {
	 	boolean quit=false;
	 	while (!quit) {
	 		OutputWindow.println("\nYour Elecronic Phone Book.");
	 		OutputWindow.println("Please choose an operation code from menu:");
	 		OutputWindow.println("1.\tAdd an entry\n2.\tDelete an entry\n3.\tFind an entry\n4.\tPrint phonebook\nTo quit: click the Exit button.\n");
	 		int operation = InputRequestor.requestInt("Please select the operation code (see output window):");
	 		//switch on the choosen operation
	 		switch (operation) {
	 			case 1: addEntry();            	
                break;
                case 2: deleteEntry();
                break;
        		case 3: searchEntry();
                break;
                case 4: printPhonebook();
                break;
        		default: OutputWindow.clear();
        		OutputWindow.println("Illegal operation code.");
        	}//close switch
        }//close while
    }//}//close main
    
	
	/*Adds an entry.
	  The user enters the first name and last name
	  that appear in the entry he wants to add.
	  The user gets a msg if the entry was added or not*/
	private static void addEntry(){
		String firstName=InputRequestor.requestString("New entry: please enter the first name");
        String lastName=InputRequestor.requestString("New entry: please enter the last name");
        String phone=InputRequestor.requestString("New entry: please enter the phone number");
        boolean add = book.addEntry(new Entry(firstName, lastName, phone));
        if(!add){
            OutputWindow.clear();
            OutputWindow.println("Sorry, your telephone book is full.");
        }
        else{
             OutputWindow.clear();
             OutputWindow.println("A new entry was added.");
       
        }
    }
        
	/*Deletes an entry.
	  The user enters the first name and last name
	  that appear in the entry he wants to delete.
	  The user gets a msg if the entry was deleted or not*/
    private static void deleteEntry(){
    	String firstName=InputRequestor.requestString("Delete entry: please enter the first name");
      	String lastName=InputRequestor.requestString("Delete entry: please enter the last name");
      	boolean delete = book.deleteEntry(new Entry(firstName, lastName, null));
      	if(!delete){
      		OutputWindow.clear();
        	OutputWindow.println("Entry does not exist.");
      	}
      	else{
      		OutputWindow.clear();
      		OutputWindow.println("Entry was deleted");
      	}
    }//close deleteEntery
    
    /*Search for an entry in the phonebook.
	  The user enters the first name and last name
	  he wants to find and gets a msg saying if the
	  entry was found or not*/
    private static void searchEntry(){
      String firstName=InputRequestor.requestString("Search entry: please enter the first name");
      String lastName=InputRequestor.requestString("Search entry: please enter the last name");
      String phone = book.searchPhone(firstName, lastName);
      if (phone == null){
        OutputWindow.clear();
        OutputWindow.println("Sorry, entry was not found.");
      }
      else{
        OutputWindow.clear();
        OutputWindow.println(new Entry(firstName, lastName, phone));
      }//else
    }//close search entry

	private static void printPhonebook(){
    	OutputWindow.clear();
    	OutputWindow.println(book);
    }
}//close class

