/**
 * An entry holds the following  details:
 * first name, last name, telephone number.
 */
public class Entry {
	private String firstName;
	private String lastName;
	private String phoneNumber;
   
   /**
  	* Constructs an Entry with given parameters.
  	* @param firstName a person's first name
  	* @param lastName a person's last name
  	* @param phoneNumber a phone number
  	*/
	public Entry(String firstName, String lastName, String phoneNumber) {
		this.firstName = firstName;
		this.lastName = lastName;
		this.phoneNumber = phoneNumber;
	}

   /**
  	* Constructs an Entry as copy of other Entry.
  	* @param otherEntry Entry to copy from.
  	*/
	public Entry(Entry otherEntry) {
		this.firstName = otherEntry.firstName;
		this.lastName = otherEntry.lastName;
		this.phoneNumber = otherEntry.phoneNumber;
	}

	
    /**
  	 * Sets a new first name.
  	 * @param firstName the new first name to be set.
  	 */
	public void setFirstName(String firstName) {
		this.firstName = firstName;
  	}
	
	/**
  	 * Sets a new last name.
  	 * @param lastName the new last name to be set.
  	 */
  	public void setLastName(String lastName) {
		this.lastName = lastName;
	}
  	  
	/**
  	 * Sets a new phone number.
  	 * @param phone the new phone number to be set.
   	 */
   	public void setPhoneNumber(String phoneNumber) {
		this.phoneNumber = phoneNumber;
	}
   	   
   	/**
	 * Returns a first name.   	   
  	 * @return the first name in this entry
  	 */
  	public String getFirstName() {
		return (this.firstName);
	}
  		
  	/**
  	 * Returns a last name.
 	 * @return the last name in this entry
  	 */
  	public String getLastName() {
		return (this.lastName);
	}
  		 
  	/**
	* @return the phone number in this entry
  	*/
  	public String getPhoneNumber() {
  	  	 return (this.phoneNumber);
  	}
  		
  	/**
	 * Compare this Entry with other Entry.
	 * @return true if Entries first and last names are equal.
  	 */
	boolean equals(Entry otherEntry) {
		return (this.firstName.equals(otherEntry.firstName) &&
			this.lastName.equals(otherEntry.lastName));
	}

  	/**
  	 * @return a string representation of an entry.
  	 */
  	public String toString(){
  	 	String str="First name: "+this.getFirstName()+"\n";
  	 	str+="Last name: "+this.getLastName()+"\n";
  	 	str+="Telephone number: "+this.getPhoneNumber()+"\n";
  	 	return str;
  	}
}//close class
