/**
 * PhoneBook is a collection of phone book entries.
 * It enables the user to create a phonebook of a fixed size
 * and then to add, delete or search entries in it. 
 */
public class PhoneBook {
	private Entry[] entries;
	private int count=0;
	
	/**
	 * Constructs a phone book of a given size
	 * @param size the number of entries the book can hold.
	 */
	 public PhoneBook(int size) {
		entries=new Entry[size];
	}
	
	/**
	* Adds a given Entry to the phonebook.
	* If the given entry already exists i.e first name and last name
	* of given entry already exists in phonebook overwrites the existing entry.
	* @return true if the entry was added false otherwise i.e. phonebook is full.
	*/
	public boolean addEntry(Entry entry) {
		//here we check if the entry we want to add already exists
		int entryIndex = findEntry(entry.getFirstName(),entry.getLastName());
		if(entryIndex != -1){//the entry exists
			entries[entryIndex]=entry; //we overwrite the existing entry with the new one
			return true; // an entry was added
		}
		else{
			//first check if phonebook is full
        	if (count==entries.length)
			    return false;
			entries[count]=entry;
			count++;
    		return true; // an entry was added
		}
    }
	
	/**
  	* Deletes a given Entry from the phonebook.
  	* @return true if the given entry exist false otherwise.
  	*/
	public boolean deleteEntry(Entry entry) {
		int entryIndex = findEntry(entry.getFirstName(),entry.getLastName());
		if (entryIndex == -1){//no such entry
      		return false;
      	}
		count--;
		for (int i=entryIndex; i<count; i++)
			entries[i]=entries[i+1];
		return true;
    }

	/**
  	 *Search an entry by first name and last name.
  	 *@return the matched entry if found and null if there is no match.
  	 */
	public String searchPhone(String firstName, String lastName) {
  	  	int found = findEntry(firstName, lastName);
      	if(found == -1){
      		return null;
      	}
      	else{
      		return entries[found].getPhoneNumber();
      	}
    }
      
    // Finds an entry by first name and last name.
    // Returns the index of the matched entry if found
    // or -1 if there is no match
	private int findEntry(String firstName, String lastName) {
		for (int i=0; i<this.count; i++) {
			Entry e=entries[i];
			if (e.getFirstName().equals(firstName) && e.getLastName().equals(lastName))
				return i;
		}
		return -1;
	}
      
    public String toString() {
       	String details = "";
		for (int i=0; i<count; i++)
			details+=entries[i] + "\n";
		return details;
	}
    
}//close class
